@@ -16,17 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with veh.  If not, see <http://www.gnu.org/licenses/>.
 
-from __future__ import with_statement
-__version__ = "0.91.0"
+__version__ = "0.92.0"
 
 from cmd import Cmd
 import sys
 import os
-from ConfigParser import ConfigParser, NoSectionError, NoOptionError
+from configparser import ConfigParser, NoSectionError, NoOptionError
 from os.path import exists as pathexists
 from os.path import splitext
 from os.path import expanduser
-from StringIO import StringIO
+from io import StringIO
 from subprocess import Popen
 from subprocess import PIPE
 import tempfile
@@ -114,7 +113,7 @@ def _get_inactive_venvs(repo):
     venvdir = os.path.join(repo, VENV_DIR)
     try:
         dirs = os.walk(venvdir).next()[1]
-    except StopIteration, e:
+    except StopIteration as e:
         return []
     activevenv = _get_active_venv(repo)
     if activevenv:
@@ -138,10 +137,10 @@ def make_venv(repo):
 def write_startup_rc(venvpath):
     with open("%s/.startup_rc" % venvpath, "w") as out:
         if sys.platform != 'darwin' and os.path.exists(expanduser("~/.bashrc")):
-            print >>out , "source %s\n" % expanduser("~/.bashrc")
+            print("source %s\n" % expanduser("~/.bashrc"), file=out)
         elif sys.platform == 'darwin' and os.path.exists(expanduser("~/.bash_profile")):
-            print >>out , "source %s\n" % expanduser("~/.bash_profile")
-        print >>out , "source %s\n" % ("%s/bin/activate" % venvpath)
+            print("source %s\n" % expanduser("~/.bash_profile"), file=out)
+        print("source %s\n" % ("%s/bin/activate" % venvpath), file=out)
 
 
 def _rm_r(dir):
@@ -192,7 +191,7 @@ def _venvsh(root, venvdir, shellcommand=None, exec_=False, pipe=False):
         command += ["-c", shellcommand]
 
     if _verbose:
-        print >>sys.stderr,  "running %s inside the venv %s in %s" % (command, venvdir, root)
+        print("running %s inside the venv %s in %s" % (command, venvdir, root), file=sys.stderr)
 
     if exec_:
         os.execve(sh, command, env if env is not None else os.environ.copy())
@@ -229,7 +228,6 @@ Using a specified rev only works on Mercurial repos right now."""
             cfg.readfp(fd, '.veh.conf')
 
         return cfg
-
     else:
         # This obviously needs fixing to be DVCS agnostic
 
@@ -238,15 +236,15 @@ Using a specified rev only works on Mercurial repos right now."""
         u = ui.ui()
         try:
             repo = hg.repository(u, repo)
-        except error.RepoError, e:
+        except error.RepoError as e:
             # repo not found
             raise
         try:
             cfgdata = repo[rev]['.veh.conf'].data()
-        except error.RepoLookupError, e:
+        except error.RepoLookupError as e:
             # revision not found
             raise
-        except error.LookupError, e:
+        except error.LookupError as e:
             # config not found
             cfgfile = os.path.join(repo.root, '.veh.conf')
             raise ConfigMissing(cfgfile)
@@ -329,7 +327,7 @@ def fill_venv(repo, cfg=None):
                     if not pathexists(cachedir):
                         os.mkdir(cachedir)
                 except:
-                    print >>sys.stderr, "%s does not exist but cannot be created" % cachedir
+                    print("%s does not exist but cannot be created" % cachedir, file=sys.stderr)
                 else:
                     cmd += " --download-cache=%s" % cachedir
 
@@ -361,17 +359,17 @@ def edit_file(filename):
             with open(filename) as srcfd:
                 data = srcfd.read()
 
-        print os.write(fd, data)
+        print(os.write(fd, data))
         os.close(fd)
-    except Exception, e:
-        print >>sys.stderr, "problem making temp file: " + str(e)
+    except Exception as e:
+        print("problem making temp file: " + str(e), file=sys.stderr)
     else:
         editor = os.environ.get("VISUAL", os.environ.get("EDITOR", "editor"))
         try:
             p = Popen([editor, tempfilename])
             p.wait()
-        except Exception, e:
-            print >>sys.stderr, "problem running editor"
+        except Exception as e:
+            print("problem running editor", file=sys.stderr)
         else:
             # Copy the temp file in
             if pathexists(filename):
@@ -436,7 +434,7 @@ def edit(repo):
     if pathexists(cfgfile):
         edit_file(cfgfile)
     else:
-        print >>sys.stderr, "%s does not exist" % cfgfile
+        print("%s does not exist" % cfgfile, file=sys.stderr)
 
 
 class SysArgsCmd(Cmd):
@@ -462,7 +460,7 @@ class VehCmd(SysArgsCmd):
     repo = None
 
     def __init__(self, **kwargs):
-        from StringIO import StringIO
+        from io import StringIO
         Cmd.__init__(self, StringIO())
         self.opts = kwargs
         global _verbose
@@ -500,7 +498,7 @@ Opens VISUAL or EDITOR or /usr/bin/edit on your repositorys config file.
         root = self._getroot()
         vehenv = _get_active_venv(root)
         if vehenv and pathexists(vehenv):
-            print root
+            print(root)
         else:
             return 1
 
@@ -510,7 +508,7 @@ Opens VISUAL or EDITOR or /usr/bin/edit on your repositorys config file.
         root = self._getroot()
         cfg = get_config(root)
         for p in cfg.items("packages"):
-            print "%s %s" % p
+            print("%s %s" % p)
 
     def do_active(self, arg):
         """Is the virtualenv active? print the path if it is."""
@@ -519,7 +517,7 @@ Opens VISUAL or EDITOR or /usr/bin/edit on your repositorys config file.
         active = _get_active_venv(root)
 
         if active and venv and os.path.abspath(venv) == os.path.abspath(active):
-            print venv
+            print(venv)
         else:
             return 1
 
@@ -542,7 +540,7 @@ affected at all."""
             deleteold = False  # default value
             try:
                 deleteold = cfg.getboolean('veh', 'delete-on-rebuild')
-            except (NoSectionError, NoOptionError), e:
+            except (NoSectionError, NoOptionError) as e:
                 pass
             if deleteold:
                 _rm_r(active)
@@ -631,15 +629,15 @@ will NOT run ipython in the virtualenv.
         root = self._getroot()
         active = _get_active_venv(root)
         if not active:
-            print >> sys.stdout, "no active venv to clone"
+            print("no active venv to clone", file=sys.stdout)
             sys.exit(1)
         newvenv = _new_venv_path(root)
         try:
             clone.clone_virtualenv(active, newvenv)
-        except Exception, e:
+        except Exception as e:
             if os.path.exists(newvenv):
                 _rm_r(newvenv)
-            print >> sys.stdout, "cloning active virtualenv failed"
+            print("cloning active virtualenv failed", file=sys.stdout)
             sys.exit(1)
 
         # Now rewrite the startup rc file
@@ -677,7 +675,7 @@ def main():
 
     # Print the version if necessary
     if o.__dict__["version"]:
-        print __version__
+        print(__version__)
         sys.exit(0)
 
     # Make the processor
@@ -687,7 +685,7 @@ def main():
     try:
         ret = cmdproc.onecmd(a)
     except IndexError:
-        print >>sys.stderr, "not enough arguments. Ask for help ?"
+        print("not enough arguments. Ask for help ?", file=sys.stderr)
     else:
         if ret:
             sys.exit(ret)
